@@ -23,7 +23,9 @@
     </div>
 
     <div class="preloaderInside">
+        <!-- Onload effects
         <i></i><i></i><i></i><i></i><i></i><i></i><i></i>
+        -->
     </div>
 
 </body>
